@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.0.2');
+use version; our $VERSION = qv('0.0.3');
 
 # Other recommended modules (uncomment to use):
 #  use IO::Prompt;
@@ -63,20 +63,30 @@ sub _request {
   
   # Web::Scraper による解析
   my $s = scraper {
-    process '//tr/td[1]/input/../../td[2][contains(. , "-")]/..',
+    process '//tr/td[2]/input/../../td[3][contains(. , "-")]/..',
     'tneko[]' => scraper {
-      process '//td[2]',
-      number => 'TEXT',
       process '//td[3]',
-      date => 'TEXT',
+      number => 'TEXT',
       process '//td[4]',
+      date => 'TEXT',
+      process '//td[5]',
       status => 'TEXT',
     },
   };
-  my $res = $s->scrape( # Shift_JISをUTF-8に変換
-              encode('utf8', decode('cp932', $self->{mech}->content() ) )
+  my $res = $s->scrape( 
+             $self->{mech}->content() 
             );
   # 得られた結果をリストで返す
+  
+  my $res2 = [];
+  foreach my $item ( @{$res->{tneko}} ) {
+    my $item2 = {};
+    foreach my $key ( keys %$item ) {
+      $item2->{$key} = encode('utf8', $item->{$key});
+    }
+    push @$res2, $item2;
+  }
+  $res->{tneko} = $res2;
   return $res->{tneko};
 }
  
@@ -110,7 +120,7 @@ WebService::KuronekoYamato - クロネコヤマトの荷物お問い合わせシ
     
     my $res = $neko->check([
       '000000000001',
-      '000000000012,
+      '000000000012',
     ]);
     
     use YAML::Syck;
